==> lxqt-panel_1.1.0.orig.tar.xz: lxqt-panel-1.1.0/plugin-directorymenu/translations/directorymenu_ca.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ca">
<context>
    <name>DirectoryMenu</name>
    <message>
        <location filename="../directorymenu.cpp" line="126"/>
        <source>Open</source>
        <translation>Obre</translation>
    </message>
    <message>
        <location filename="../directorymenu.cpp" line="130"/>
        <source>Open in terminal</source>
        <translation>Obre al terminal</translation>
    </message>
</context>
<context>
    <name>DirectoryMenuConfiguration</name>
    <message>
        <location filename="../directorymenuconfiguration.ui" line="14"/>
        <source>Directory Menu Settings</source>
        <translation>Ajusts del menú de directoris</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.ui" line="20"/>
        <source>Appearance</source>
        <translation>Aparença</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.ui" line="26"/>
        <source>Base directory:</source>
        <translation>Directori base:</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.ui" line="39"/>
        <source>BaseDirectoryName</source>
        <translation>NomDirectoriBase</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.ui" line="46"/>
        <source>Icon:</source>
        <translation>Icona:</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.ui" line="66"/>
        <source>Label</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.ui" line="86"/>
        <source>Button style</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.ui" line="103"/>
        <source>Terminal</source>
        <translation>Terminal</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.ui" line="96"/>
        <location filename="../directorymenuconfiguration.cpp" line="131"/>
        <source>Choose Default Terminal</source>
        <translation>Trieu el terminal predeterminat</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.cpp" line="54"/>
        <source>Only icon</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.cpp" line="55"/>
        <source>Only text</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.cpp" line="56"/>
        <source>Icon and text</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.cpp" line="115"/>
        <source>Choose Base Directory</source>
        <translation>Trieu el directori base</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.cpp" line="164"/>
        <source>Choose Icon</source>
        <translation>Trieu la icona</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.cpp" line="164"/>
        <source>Icons (*.png *.xpm *.jpg *.svg)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.cpp" line="188"/>
        <source>Choose Label</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.cpp" line="189"/>
        <source>Label:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.cpp" line="173"/>
        <source>Directory Menu</source>
        <translation>Menú de directoris</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.cpp" line="173"/>
        <source>An error occurred while loading the icon.</source>
        <translation>S&apos;ha produït un error mentre es carregava la icona.</translation>
    </message>
</context>
</TS>

==> lxqt-panel_1.4.0.orig.tar.xz: lxqt-panel-1.4.0/plugin-directorymenu/translations/directorymenu_ca.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ca">
<context>
    <name>DirectoryMenu</name>
    <message>
        <location filename="../directorymenu.cpp" line="126"/>
        <source>Open</source>
        <translation>Obre</translation>
    </message>
    <message>
        <location filename="../directorymenu.cpp" line="130"/>
        <source>Open in terminal</source>
        <translation>Obre al terminal</translation>
    </message>
</context>
<context>
    <name>DirectoryMenuConfiguration</name>
    <message>
        <location filename="../directorymenuconfiguration.ui" line="14"/>
        <source>Directory Menu Settings</source>
        <translation>Ajusts del menú de directoris</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.ui" line="20"/>
        <source>Appearance</source>
        <translation>Aparença</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.ui" line="26"/>
        <source>Base directory:</source>
        <translation>Directori base:</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.ui" line="39"/>
        <source>BaseDirectoryName</source>
        <translation>NomDirectoriBase</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.ui" line="46"/>
        <source>Icon:</source>
        <translation>Icona:</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.ui" line="66"/>
        <source>Label</source>
        <translation>Etiqueta</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.ui" line="86"/>
        <source>Button style</source>
        <translation>Estil de botó</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.ui" line="103"/>
        <source>Terminal</source>
        <translation>Terminal</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.ui" line="96"/>
        <location filename="../directorymenuconfiguration.cpp" line="131"/>
        <source>Choose Default Terminal</source>
        <translation>Trieu el terminal predeterminat</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.cpp" line="54"/>
        <source>Only icon</source>
        <translation>Només icones</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.cpp" line="55"/>
        <source>Only text</source>
        <translation>Només text</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.cpp" line="56"/>
        <source>Icon and text</source>
        <translation>Text i icones</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.cpp" line="115"/>
        <source>Choose Base Directory</source>
        <translation>Trieu el directori base</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.cpp" line="164"/>
        <source>Choose Icon</source>
        <translation>Trieu la icona</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.cpp" line="164"/>
        <source>Icons (*.png *.xpm *.jpg *.svg)</source>
        <translation>Icones (*.png *.xpm *.jpg *.svg)</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.cpp" line="188"/>
        <source>Choose Label</source>
        <translation>Escolliu una etiqueta</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.cpp" line="189"/>
        <source>Label:</source>
        <translation>Etiqueta:</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.cpp" line="173"/>
        <source>Directory Menu</source>
        <translation>Menú de directoris</translation>
    </message>
    <message>
        <location filename="../directorymenuconfiguration.cpp" line="173"/>
        <source>An error occurred while loading the icon.</source>
        <translation>S&apos;ha produït un error mentre es carregava la icona.</translation>
    </message>
</context>
</TS>
